<!DOCTYPE html>
<html>
	<head>
		<title>On-call positions</title>
	</head>
	<body>
		<h1>On-call positions</h1>
		<table>
			<thead>
				<tr>
					<th>Position</th>
					<th>On-call</th>
				</tr>
			</thead>
			<tbody>
{% for on_call in object_list %}
				<tr>
					<td>
						<a href="{% url on-call on_call.slug %}">
							{{on_call.slug}}
						</a>
					</td>
					<td>{{on_call.get_on_call}}</td>
				</tr>
{% empty %}
				<tr>
					<td colspan="2">
						No positions yet.
					</td>
				</tr>
{% endfor %}
			</tbody>
		</table>
	</body>
</html>
